"use strict";
const Electron = require('electron');
const fs = require('fs');
const gapp = require('./package.json');

const APP_NAME = process.env.APP_NAME = gapp.name;
const APP_DESC = process.env.APP_DESC = gapp.name;
const APP_VER = process.env.APP_VER = gapp.version;

process.env.APPDATA = Electron.app.getPath('appData') + '/' + APP_NAME + '/';

let confDir = process.env.APPDATA + 'persistent/config';
let oldConfDir = process.env.APPDATA + 'config';

let confFile = confDir + '/config.json';
let oldConfFile = oldConfDir + '/config.json';

let appConfig = {};
let existingConfig = {};

if ( fs.existsSync(confFile) ) {
	existingConfig = fs.readFileSync(confFile);
	existingConfig = JSON.parse(existingConfig);
	appConfig = Object.assign({}, existingConfig, appConfig);
}

appConfig.APP_NAME = APP_NAME;
appConfig.APP_DESC = APP_DESC;
appConfig.serverPath = (process.platform === 'win32' ? `./app/${appConfig.APP_NAME}.exe` : `./app/${appConfig.APP_NAME}`);

appConfig.getUserConfig = () => {
	if ( ! fs.existsSync(confFile) ) {
		return {};
	}

	let userConfig = fs.readFileSync(confFile);
	return JSON.parse(userConfig);
};



appConfig.loadUserConfig = () => {
	if ( ! fs.existsSync(confFile) ) {
		return {};
	}

	let userConfig = fs.readFileSync(confFile);
	
	userConfig = JSON.parse(userConfig);
	appConfig = Object.assign({}, userConfig, appConfig);
};

appConfig.checkUserConfig = () => {
	if ( fs.existsSync(confFile) || ! fs.existsSync(oldConfFile)) {
		if ( fs.existsSync(confDir) && fs.existsSync(oldConfDir) )
			fs.rmdirSync(oldConfDir);

		return;
	}

	if ( ! fs.existsSync(confDir) ) {
		fs.mkdirSync(confDir, { recursive: true });
	}
	
	fs.renameSync(oldConfFile, confFile);
	fs.rmdirSync(oldConfDir);
};
module.exports = appConfig;
